@@ -3,7 +3,7 @@
 //
 // Contents: Routines that use connection handles
 //
-// Microsoft Drivers 5.8 for PHP for SQL Server
+// Microsoft Drivers 5.9 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -35,10 +35,8 @@ unsigned int current_log_subsystem = LOG_CONN;
 
 struct date_as_string_func {
 
-    static void func( connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ TSRMLS_DC )
+    static void func( connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ )
     {
-        TSRMLS_C;   // show as used to avoid a warning
-
         ss_sqlsrv_conn* ss_conn = static_cast<ss_sqlsrv_conn*>( conn );
 
         if( zend_is_true( value )) {
@@ -52,10 +50,8 @@ struct date_as_string_func {
 
 struct format_decimals_func
 {
-    static void func(connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ TSRMLS_DC)
+    static void func(connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/)
     {
-        TSRMLS_C;   // show as used to avoid a warning
-
         ss_sqlsrv_conn* ss_conn = static_cast<ss_sqlsrv_conn*>(conn);
 
         if (zend_is_true(value)) {
@@ -70,10 +66,8 @@ struct format_decimals_func
 struct decimal_places_func
 {
 
-    static void func(connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ TSRMLS_DC)
+    static void func(connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/)
     {
-        TSRMLS_C;   // show as used to avoid a warning
-
         // first check if the input is an integer
         if (Z_TYPE_P(value) != IS_LONG) {
             THROW_SS_ERROR(conn, SQLSRV_ERROR_INVALID_DECIMAL_PLACES);
@@ -91,7 +85,7 @@ struct decimal_places_func
 
 struct conn_char_set_func {
 
-    static void func( connection_option const* /*option*/, _Inout_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ TSRMLS_DC )
+    static void func( connection_option const* /*option*/, _Inout_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ )
     {
          convert_to_string( value );
          const char* encoding = Z_STRVAL_P( value );
@@ -121,9 +115,8 @@ struct conn_char_set_func {
 
 struct bool_conn_str_func {
 
-    static void func( _In_ connection_option const* option, _In_ zval* value, sqlsrv_conn* /*conn*/, _Out_ std::string& conn_str TSRMLS_DC )
+    static void func( _In_ connection_option const* option, _In_ zval* value, sqlsrv_conn* /*conn*/, _Out_ std::string& conn_str )
     {
-        TSRMLS_C;
         char const* val_str;
         if( zend_is_true( value )) {
             val_str = "yes";
@@ -140,9 +133,8 @@ struct bool_conn_str_func {
 
 struct int_conn_str_func {
 
-    static void func( _In_ connection_option const* option, _In_ zval* value, sqlsrv_conn* /*conn*/, _Out_ std::string& conn_str TSRMLS_DC )
+    static void func( _In_ connection_option const* option, _In_ zval* value, sqlsrv_conn* /*conn*/, _Out_ std::string& conn_str )
     {
-        TSRMLS_C;
         SQLSRV_ASSERT( Z_TYPE_P( value ) == IS_LONG, "An integer is expected for this keyword" ) 
 
         std::string val_str = std::to_string( Z_LVAL_P( value ));
@@ -157,11 +149,11 @@ struct int_conn_str_func {
 template <unsigned int Attr>
 struct int_conn_attr_func {
 
-    static void func( connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ TSRMLS_DC )
+    static void func( connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ )
     {
         try {
         
-            core::SQLSetConnectAttr( conn, Attr, reinterpret_cast<SQLPOINTER>( Z_LVAL_P( value )), SQL_IS_UINTEGER TSRMLS_CC );
+            core::SQLSetConnectAttr( conn, Attr, reinterpret_cast<SQLPOINTER>( Z_LVAL_P( value )), SQL_IS_UINTEGER );
         }
         catch( core::CoreException& ) {
             throw;
@@ -172,10 +164,10 @@ struct int_conn_attr_func {
 template <unsigned int Attr>
 struct bool_conn_attr_func {
 
-    static void func( connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ TSRMLS_DC )
+    static void func( connection_option const* /*option*/, _In_ zval* value, _Inout_ sqlsrv_conn* conn, std::string& /*conn_str*/ )
     {
          try {
-             core::SQLSetConnectAttr(conn, Attr, reinterpret_cast<SQLPOINTER>((zend_long)zend_is_true(value)), SQL_IS_UINTEGER TSRMLS_CC);
+             core::SQLSetConnectAttr(conn, Attr, reinterpret_cast<SQLPOINTER>((zend_long)zend_is_true(value)), SQL_IS_UINTEGER);
         
         }
         catch( core::CoreException& ) {
@@ -187,15 +179,15 @@ struct bool_conn_attr_func {
 
 //// *** internal functions ***
 
-void sqlsrv_conn_close_stmts( _Inout_ ss_sqlsrv_conn* conn TSRMLS_DC );
+void sqlsrv_conn_close_stmts( _Inout_ ss_sqlsrv_conn* conn );
 void validate_conn_options( _Inout_ sqlsrv_context& ctx, _In_ zval* user_options_z, _Inout_ char** uid, _Inout_ char** pwd, 
-                            _Inout_ HashTable* ss_conn_options_ht TSRMLS_DC );
-void validate_stmt_options( _Inout_ sqlsrv_context& ctx, _Inout_ zval* stmt_options, _Inout_ HashTable* ss_stmt_options_ht TSRMLS_DC );
+                            _Inout_ HashTable* ss_conn_options_ht );
+void validate_stmt_options( _Inout_ sqlsrv_context& ctx, _Inout_ zval* stmt_options, _Inout_ HashTable* ss_stmt_options_ht );
 void add_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, 
-                         _Inout_ HashTable* options_ht, _Inout_ zval* data TSRMLS_DC );
-void add_stmt_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, _Inout_ HashTable* options_ht, _Inout_ zval* data TSRMLS_DC );
-int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, _Inout_ zval const* value_z TSRMLS_DC );   
-int get_stmt_option_key( _In_ zend_string* key, _In_ size_t key_len TSRMLS_DC );
+                         _Inout_ HashTable* options_ht, _Inout_ zval* data );
+void add_stmt_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, _Inout_ HashTable* options_ht, _Inout_ zval* data );
+int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, _Inout_ zval const* value_z );   
+int get_stmt_option_key( _In_ zend_string* key, _In_ size_t key_len );
 
 }
 
@@ -633,7 +625,7 @@ PHP_FUNCTION ( sqlsrv_connect )
     g_ss_henv_cp->set_func(_FN_);
     g_ss_henv_ncp->set_func(_FN_);
 
-    reset_errors( TSRMLS_C );
+    reset_errors();
 
     const char* server = NULL;
     zval* options_z = NULL;
@@ -643,7 +635,7 @@ PHP_FUNCTION ( sqlsrv_connect )
     zval conn_z;
     ZVAL_UNDEF(&conn_z);
     // get the server name and connection options
-    int result = zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "s|a", &server, &server_len, &options_z );
+    int result = zend_parse_parameters( ZEND_NUM_ARGS(), "s|a", &server, &server_len, &options_z );
     
     CHECK_CUSTOM_ERROR(( result == FAILURE ), *g_ss_henv_cp, SS_SQLSRV_ERROR_INVALID_FUNCTION_PARAMETER, "sqlsrv_connect" ) {
         RETURN_FALSE;
@@ -659,26 +651,26 @@ PHP_FUNCTION ( sqlsrv_connect )
         ALLOC_HASHTABLE( ss_conn_options_ht );
         
         core::sqlsrv_zend_hash_init( *g_ss_henv_cp, ss_conn_options_ht, 10 /* # of buckets */, 
-                                 ZVAL_PTR_DTOR, 0 /*persistent*/ TSRMLS_CC );
+                                 ZVAL_PTR_DTOR, 0 /*persistent*/ );
    
         // Either of g_ss_henv_cp or g_ss_henv_ncp can be used to propagate the error.
-        ::validate_conn_options( *g_ss_henv_cp, options_z, &uid, &pwd, ss_conn_options_ht TSRMLS_CC );   
+        ::validate_conn_options( *g_ss_henv_cp, options_z, &uid, &pwd, ss_conn_options_ht );   
      
         // call the core connect function  
         conn = static_cast<ss_sqlsrv_conn*>( core_sqlsrv_connect( *g_ss_henv_cp, *g_ss_henv_ncp, &core::allocate_conn<ss_sqlsrv_conn>,
                                                                   server, uid, pwd, ss_conn_options_ht, ss_error_handler,  
-                                                                  SS_CONN_OPTS, NULL, "sqlsrv_connect" TSRMLS_CC )); 
+                                                                  SS_CONN_OPTS, NULL, "sqlsrv_connect" )); 
         
         SQLSRV_ASSERT( conn != NULL, "sqlsrv_connect: Invalid connection returned.  Exception should have been thrown." );
         
         // create a bunch of statements
         ALLOC_HASHTABLE( stmts );
     
-        core::sqlsrv_zend_hash_init( *g_ss_henv_cp, stmts, 5, NULL /* dtor */, 0 /* persistent */ TSRMLS_CC );
+        core::sqlsrv_zend_hash_init( *g_ss_henv_cp, stmts, 5, NULL /* dtor */, 0 /* persistent */ );
 
         // register the connection with the PHP runtime 
         
-        ss::zend_register_resource(conn_z, conn, ss_sqlsrv_conn::descriptor, ss_sqlsrv_conn::resource_name TSRMLS_CC);
+        ss::zend_register_resource(conn_z, conn, ss_sqlsrv_conn::descriptor, ss_sqlsrv_conn::resource_name);
 
         conn->stmts = stmts;
         stmts.transferred();
@@ -739,7 +731,7 @@ PHP_FUNCTION( sqlsrv_begin_transaction )
 
     try {
 
-        core_sqlsrv_begin_transaction( conn TSRMLS_CC );
+        core_sqlsrv_begin_transaction( conn );
         conn->in_transaction = true;
         RETURN_TRUE;
     }
@@ -778,7 +770,7 @@ PHP_FUNCTION( sqlsrv_close )
     ss_sqlsrv_conn* conn = NULL;
     sqlsrv_context_auto_ptr error_ctx;
 
-    reset_errors( TSRMLS_C );
+    reset_errors();
     
     try {
         
@@ -786,10 +778,10 @@ PHP_FUNCTION( sqlsrv_close )
         error_ctx = new (sqlsrv_malloc( sizeof( sqlsrv_context ))) sqlsrv_context( 0, ss_error_handler, NULL );
         error_ctx->set_func(_FN_);
 
-        if( zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "r", &conn_r) == FAILURE ) {
+        if( zend_parse_parameters(ZEND_NUM_ARGS(), "r", &conn_r) == FAILURE ) {
         
              // Check if it was a zval
-            int zr = zend_parse_parameters( ZEND_NUM_ARGS() TSRMLS_CC, "z", &conn_r );
+            int zr = zend_parse_parameters( ZEND_NUM_ARGS(), "z", &conn_r );
             CHECK_CUSTOM_ERROR(( zr == FAILURE ), error_ctx, SS_SQLSRV_ERROR_INVALID_FUNCTION_PARAMETER, _FN_ ) {
                 throw ss::SSException();
             }   
@@ -803,7 +795,7 @@ PHP_FUNCTION( sqlsrv_close )
             }
         }
         SQLSRV_ASSERT( conn_r != NULL, "sqlsrv_close: conn_r was null" );
-        conn = static_cast<ss_sqlsrv_conn*>( zend_fetch_resource( Z_RES_P( conn_r ) TSRMLS_CC, ss_sqlsrv_conn::resource_name, ss_sqlsrv_conn::descriptor ));
+        conn = static_cast<ss_sqlsrv_conn*>( zend_fetch_resource( Z_RES_P( conn_r ), ss_sqlsrv_conn::resource_name, ss_sqlsrv_conn::descriptor ));
 
         // if sqlsrv_close was called on an already closed connection then we just return success.
         if ( Z_RES_TYPE_P( conn_r ) == RSRC_INVALID_TYPE) {
@@ -820,9 +812,13 @@ PHP_FUNCTION( sqlsrv_close )
         // cause any variables still holding a reference to this to be invalid so they cause
         // an error when passed to a sqlsrv function.  There's nothing we can do if the 
         // removal fails, so we just log it and move on.
-        if( zend_list_close( Z_RES_P( conn_r ) ) == FAILURE ) {
-            LOG( SEV_ERROR, "Failed to remove connection resource %1!d!", Z_RES_HANDLE_P( conn_r ));
+#if PHP_VERSION_ID < 80000
+        if (zend_list_close(Z_RES_P(conn_r)) == FAILURE) {
+            LOG(SEV_ERROR, "Failed to remove connection resource %1!d!", Z_RES_HANDLE_P(conn_r));
         }
+#else
+        zend_list_close(Z_RES_P(conn_r));
+#endif
 
         // when conn_r is first parsed in zend_parse_parameters, conn_r becomes a zval that points to a zend_resource with a refcount of 2
         // need to DELREF here so the refcount becomes 1 and conn_r can be appropriate destroyed by the garbage collector when it goes out of scope
@@ -842,7 +838,7 @@ PHP_FUNCTION( sqlsrv_close )
     }
 }
 
-void __cdecl sqlsrv_conn_dtor( _Inout_ zend_resource *rsrc TSRMLS_DC )
+void __cdecl sqlsrv_conn_dtor( _Inout_ zend_resource *rsrc )
 {
     // Without sqlsrv_close(), this function is invoked by php during the final clean up stage. 
     // To prevent memory/resource leaks, no more logging at this point.
@@ -855,10 +851,10 @@ void __cdecl sqlsrv_conn_dtor( _Inout_ zend_resource *rsrc TSRMLS_DC )
     conn->set_func(__func__);
 
     // close all statements associated with the connection.
-    sqlsrv_conn_close_stmts( conn TSRMLS_CC );
+    sqlsrv_conn_close_stmts( conn );
 
     // close the connection itself.
-    core_sqlsrv_close( conn TSRMLS_CC );
+    core_sqlsrv_close( conn );
     
     rsrc->ptr = NULL;
 }
@@ -901,7 +897,7 @@ PHP_FUNCTION( sqlsrv_commit )
     try {
 
         conn->in_transaction = false;
-        core_sqlsrv_commit( conn TSRMLS_CC );
+        core_sqlsrv_commit( conn );
         RETURN_TRUE;
 
     }
@@ -955,7 +951,7 @@ PHP_FUNCTION( sqlsrv_rollback )
     try {
         
         conn->in_transaction = false;
-        core_sqlsrv_rollback( conn TSRMLS_CC );
+        core_sqlsrv_rollback( conn );
         RETURN_TRUE;
     }
     catch( core::CoreException& ){
@@ -975,28 +971,22 @@ PHP_FUNCTION( sqlsrv_rollback )
 
 PHP_FUNCTION( sqlsrv_client_info )
 {
-
     LOG_FUNCTION( "sqlsrv_client_info" );
     ss_sqlsrv_conn* conn = NULL;
     PROCESS_PARAMS( conn, "r", _FN_, 0 );
     
     try {
+        core_sqlsrv_get_client_info(conn, return_value);
 
-        core_sqlsrv_get_client_info( conn, return_value TSRMLS_CC );
-        
         // Add the sqlsrv driver's file version
         //Declarations below eliminate compiler warnings about string constant to char* conversions
         const char* extver = "ExtensionVer";
         std::string filever = VER_FILEVERSION_STR;
-        core::sqlsrv_add_assoc_string( *conn, return_value, extver, &filever[0], 1 /*duplicate*/ TSRMLS_CC );
-    }
-
-    catch( core::CoreException& ) {
+        add_assoc_string(return_value, extver, &filever[0]);
+    } catch (core::CoreException&) {
         RETURN_FALSE;
-    }
-    catch( ... ) {
-
-        DIE( "sqlsrv_client_info: Unknown exception caught." );
+    } catch (...) {
+        DIE("sqlsrv_client_info: Unknown exception caught.");
     }
 }
 
@@ -1019,20 +1009,15 @@ PHP_FUNCTION( sqlsrv_client_info )
 PHP_FUNCTION( sqlsrv_server_info )
 {
     try {
-
-        LOG_FUNCTION( "sqlsrv_server_info" );
+        LOG_FUNCTION("sqlsrv_server_info");
         ss_sqlsrv_conn* conn = NULL;
-        PROCESS_PARAMS( conn, "r", _FN_, 0 );
+        PROCESS_PARAMS(conn, "r", _FN_, 0);
 
-        core_sqlsrv_get_server_info( conn, return_value TSRMLS_CC );
-    }
-
-    catch( core::CoreException& ) {
+        core_sqlsrv_get_server_info(conn, return_value);
+    } catch (core::CoreException&) {
         RETURN_FALSE;
-    }
-    catch( ... ) {
-
-        DIE( "sqlsrv_server_info: Unknown exception caught." );
+    } catch (...) {
+        DIE("sqlsrv_server_info: Unknown exception caught.");
     }
 }
 
@@ -1093,9 +1078,9 @@ PHP_FUNCTION( sqlsrv_prepare )
             // Initialize the options array to be passed to the core layer
             ALLOC_HASHTABLE( ss_stmt_options_ht );
             core::sqlsrv_zend_hash_init( *conn , ss_stmt_options_ht, 5 /* # of buckets */, 
-                                         ZVAL_PTR_DTOR, 0 /*persistent*/ TSRMLS_CC );
+                                         ZVAL_PTR_DTOR, 0 /*persistent*/ );
             
-            validate_stmt_options( *conn, options_z, ss_stmt_options_ht TSRMLS_CC );
+            validate_stmt_options( *conn, options_z, ss_stmt_options_ht );
         
         }
 
@@ -1114,9 +1099,9 @@ PHP_FUNCTION( sqlsrv_prepare )
 
         stmt = static_cast<ss_sqlsrv_stmt*>( core_sqlsrv_create_stmt( conn, core::allocate_stmt<ss_sqlsrv_stmt>, 
                                                                       ss_stmt_options_ht, SS_STMT_OPTS, 
-                                                                      ss_error_handler, NULL TSRMLS_CC ) );
+                                                                      ss_error_handler, NULL ) );
        
-        core_sqlsrv_prepare( stmt, sql, sql_len TSRMLS_CC );
+        core_sqlsrv_prepare( stmt, sql, sql_len );
         
         if (params_z) {
             stmt->params_z = (zval *)sqlsrv_malloc(sizeof(zval));
@@ -1126,13 +1111,13 @@ PHP_FUNCTION( sqlsrv_prepare )
         stmt->prepared = true;
 
         // register the statement with the PHP runtime        
-        ss::zend_register_resource( stmt_z, stmt, ss_sqlsrv_stmt::descriptor, ss_sqlsrv_stmt::resource_name TSRMLS_CC );
+        ss::zend_register_resource( stmt_z, stmt, ss_sqlsrv_stmt::descriptor, ss_sqlsrv_stmt::resource_name );
 
         // store the resource id with the connection so the connection 
         // can release this statement when it closes.
         zend_long next_index = zend_hash_next_free_element( conn->stmts );
   
-        core::sqlsrv_zend_hash_index_update(*conn, conn->stmts, next_index, &stmt_z TSRMLS_CC);
+        core::sqlsrv_zend_hash_index_update(*conn, conn->stmts, next_index, &stmt_z);
 
         stmt->conn_index = next_index;
 
@@ -1150,7 +1135,7 @@ PHP_FUNCTION( sqlsrv_prepare )
             stmt->~ss_sqlsrv_stmt();
         }
         if (!Z_ISUNDEF(stmt_z)) {
-            free_stmt_resource(&stmt_z TSRMLS_CC);
+            free_stmt_resource(&stmt_z);
         }
 
         RETURN_FALSE;
@@ -1216,9 +1201,9 @@ PHP_FUNCTION( sqlsrv_query )
             // Initialize the options array to be passed to the core layer
             ALLOC_HASHTABLE( ss_stmt_options_ht );
             core::sqlsrv_zend_hash_init( *conn , ss_stmt_options_ht, 5 /* # of buckets */, ZVAL_PTR_DTOR, 
-                                         0 /*persistent*/ TSRMLS_CC );
+                                         0 /*persistent*/ );
             
-            validate_stmt_options( *conn, options_z, ss_stmt_options_ht TSRMLS_CC );    
+            validate_stmt_options( *conn, options_z, ss_stmt_options_ht );    
         }
 
         if( params_z && Z_TYPE_P( params_z ) != IS_ARRAY ) {
@@ -1236,7 +1221,7 @@ PHP_FUNCTION( sqlsrv_query )
 
         stmt = static_cast<ss_sqlsrv_stmt*>( core_sqlsrv_create_stmt( conn, core::allocate_stmt<ss_sqlsrv_stmt>, 
                                                                       ss_stmt_options_ht, SS_STMT_OPTS, 
-                                                                      ss_error_handler, NULL TSRMLS_CC ) );
+                                                                      ss_error_handler, NULL ) );
 
         if( params_z ) {
             stmt->params_z = (zval *)sqlsrv_malloc(sizeof(zval));
@@ -1245,18 +1230,18 @@ PHP_FUNCTION( sqlsrv_query )
 
         stmt->set_func( "sqlsrv_query" );
 
-        bind_params( stmt TSRMLS_CC );
+        bind_params( stmt );
 
         // execute the statement
-        core_sqlsrv_execute( stmt TSRMLS_CC, sql, static_cast<int>( sql_len ) );
+        core_sqlsrv_execute( stmt, sql, static_cast<int>( sql_len ) );
        
         // register the statement with the PHP runtime 
-        ss::zend_register_resource(stmt_z, stmt, ss_sqlsrv_stmt::descriptor, ss_sqlsrv_stmt::resource_name TSRMLS_CC);
+        ss::zend_register_resource(stmt_z, stmt, ss_sqlsrv_stmt::descriptor, ss_sqlsrv_stmt::resource_name);
         // store the resource id with the connection so the connection 
         // can release this statement when it closes.
         zend_ulong next_index = zend_hash_next_free_element( conn->stmts );
      
-        core::sqlsrv_zend_hash_index_update(*conn, conn->stmts, next_index, &stmt_z TSRMLS_CC);
+        core::sqlsrv_zend_hash_index_update(*conn, conn->stmts, next_index, &stmt_z);
         stmt->conn_index = next_index;
         stmt.transferred();
 
@@ -1271,7 +1256,7 @@ PHP_FUNCTION( sqlsrv_query )
             stmt->~ss_sqlsrv_stmt();
         }
         if (!Z_ISUNDEF(stmt_z)) {
-            free_stmt_resource(&stmt_z TSRMLS_CC);
+            free_stmt_resource(&stmt_z);
         }
 
         RETURN_FALSE;
@@ -1282,11 +1267,16 @@ PHP_FUNCTION( sqlsrv_query )
     }
 }
 
-void free_stmt_resource( _Inout_ zval* stmt_z TSRMLS_DC )
+void free_stmt_resource( _Inout_ zval* stmt_z )
 {
-    if( FAILURE == zend_list_close( Z_RES_P( stmt_z ))) {
+#if PHP_VERSION_ID < 80000
+    if (FAILURE == zend_list_close(Z_RES_P(stmt_z))) {
         LOG(SEV_ERROR, "Failed to remove stmt resource %1!d!", Z_RES_HANDLE_P(stmt_z));
     }
+#else
+    zend_list_close(Z_RES_P(stmt_z));
+#endif
+
     ZVAL_NULL( stmt_z );
     zval_ptr_dtor(stmt_z);
 }
@@ -1298,7 +1288,7 @@ namespace {
 // must close all statement handles opened by this connection before closing the connection
 // no errors are returned, since close should always succeed
 
-void sqlsrv_conn_close_stmts( _Inout_ ss_sqlsrv_conn* conn TSRMLS_DC )
+void sqlsrv_conn_close_stmts( _Inout_ ss_sqlsrv_conn* conn )
 {
     //pre-condition check
     SQLSRV_ASSERT(( conn->handle() != NULL ), "sqlsrv_conn_close_stmts: Connection handle is NULL. Trying to destroy an "
@@ -1336,9 +1326,13 @@ void sqlsrv_conn_close_stmts( _Inout_ ss_sqlsrv_conn* conn TSRMLS_DC )
 
         // this would call the destructor on the statement.
         // There's nothing we can do if the removal fails, so we just log it and move on.
-        if( zend_list_close( Z_RES_P(rsrc_ptr) ) == FAILURE ) {
+#if PHP_VERSION_ID < 80000
+        if (zend_list_close(Z_RES_P(rsrc_ptr)) == FAILURE) {
             LOG(SEV_ERROR, "Failed to remove statement resource %1!d! when closing the connection", Z_RES_HANDLE_P(rsrc_ptr));
         }
+#else
+        zend_list_close(Z_RES_P(rsrc_ptr));
+#endif
     } ZEND_HASH_FOREACH_END();
 
     zend_hash_destroy( conn->stmts );
@@ -1346,7 +1340,7 @@ void sqlsrv_conn_close_stmts( _Inout_ ss_sqlsrv_conn* conn TSRMLS_DC )
     conn->stmts = NULL;
 }
 
-int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, _Inout_ zval const* value_z TSRMLS_DC )    
+int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, _Inout_ zval const* value_z )    
 {
     for( int i=0; SS_CONN_OPTS[i].conn_option_key != SQLSRV_CONN_OPTION_INVALID; ++i )
     {
@@ -1389,7 +1383,7 @@ int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In
 
                     bool valid = true;
                     if( stricmp( SS_CONN_OPTS[i].sqlsrv_name, SSConnOptionNames::Authentication ) == 0 ) {
-                        valid = core_is_authentication_option_valid( value, value_len );
+                        valid = AzureADOptions::isAuthValid(value, value_len);
                     }
 
                     CHECK_CUSTOM_ERROR( !valid, ctx, SS_SQLSRV_ERROR_INVALID_AUTHENTICATION_OPTION, SS_CONN_OPTS[i].sqlsrv_name ) {
@@ -1399,7 +1393,10 @@ int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In
 
                     break;
                 }
-            }
+                case CONN_ATTR_INVALID:
+                    SQLSRV_ASSERT(false, "Should not have reached CONN_ATTR_INVALID.");
+                    break;
+             }
 
             return SS_CONN_OPTS[i].conn_option_key;
         }
@@ -1407,7 +1404,7 @@ int get_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In
     return SQLSRV_CONN_OPTION_INVALID;
 }
 
-int get_stmt_option_key( _In_ zend_string* key, _In_ size_t key_len TSRMLS_DC )
+int get_stmt_option_key( _In_ zend_string* key, _In_ size_t key_len )
 {
     for( int i = 0; SS_STMT_OPTS[i].key != SQLSRV_STMT_OPTION_INVALID; ++i )
     {
@@ -1419,9 +1416,9 @@ int get_stmt_option_key( _In_ zend_string* key, _In_ size_t key_len TSRMLS_DC )
 }
 
 void add_stmt_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, 
-                         _Inout_ HashTable* options_ht, _Inout_ zval* data TSRMLS_DC )
+                         _Inout_ HashTable* options_ht, _Inout_ zval* data )
 {
-    int option_key = ::get_stmt_option_key( key, key_len TSRMLS_CC );   
+    int option_key = ::get_stmt_option_key( key, key_len );   
     
     CHECK_CUSTOM_ERROR((option_key == SQLSRV_STMT_OPTION_INVALID ), ctx, SQLSRV_ERROR_INVALID_OPTION_KEY, ZSTR_VAL( key ) ) {
 
@@ -1429,27 +1426,27 @@ void add_stmt_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _I
     }        
 
     Z_TRY_ADDREF_P(data);      // inc the ref count since this is going into the options_ht too.
-    core::sqlsrv_zend_hash_index_update( ctx, options_ht, option_key, data TSRMLS_CC );
+    core::sqlsrv_zend_hash_index_update( ctx, options_ht, option_key, data );
 }
 
 void add_conn_option_key( _Inout_ sqlsrv_context& ctx, _In_ zend_string* key, _In_ size_t key_len, 
-                         _Inout_ HashTable* options_ht, _Inout_ zval* data TSRMLS_DC )
+                         _Inout_ HashTable* options_ht, _Inout_ zval* data )
 {
-    int option_key = ::get_conn_option_key( ctx, key, key_len, data TSRMLS_CC );    
+    int option_key = ::get_conn_option_key( ctx, key, key_len, data );    
     CHECK_CUSTOM_ERROR((option_key == SQLSRV_STMT_OPTION_INVALID ), ctx, SS_SQLSRV_ERROR_INVALID_OPTION, ZSTR_VAL( key ) ) {
 
         throw ss::SSException();
     }        
 
     Z_TRY_ADDREF_P(data);      // inc the ref count since this is going into the options_ht too.
-    core::sqlsrv_zend_hash_index_update( ctx, options_ht, option_key, data TSRMLS_CC );
+    core::sqlsrv_zend_hash_index_update( ctx, options_ht, option_key, data );
 }
 
 // Iterates through the list of statement options provided by the user and validates them 
 // against the list of supported statement options by this driver. After validation
 // creates a Hashtable of statement options to be sent to the core layer for processing.
 
-void validate_stmt_options( _Inout_ sqlsrv_context& ctx, _Inout_ zval* stmt_options, _Inout_ HashTable* ss_stmt_options_ht TSRMLS_DC )
+void validate_stmt_options( _Inout_ sqlsrv_context& ctx, _Inout_ zval* stmt_options, _Inout_ HashTable* ss_stmt_options_ht )
 {
     try {
         if( stmt_options ) {
@@ -1471,7 +1468,7 @@ void validate_stmt_options( _Inout_ sqlsrv_context& ctx, _Inout_ zval* stmt_opti
                 }
                 else if ( key != NULL ) {
                     key_len = ZSTR_LEN( key ) + 1;
-                    add_stmt_option_key( ctx, key, key_len, ss_stmt_options_ht, data TSRMLS_CC );
+                    add_stmt_option_key( ctx, key, key_len, ss_stmt_options_ht, data );
                 }
                 else {
                     DIE( "validate_stmt_options: key was null." );
@@ -1489,7 +1486,7 @@ void validate_stmt_options( _Inout_ sqlsrv_context& ctx, _Inout_ zval* stmt_opti
 // against the predefined list of supported connection options by this driver. After validation
 // creates a Hashtable of connection options to be sent to the core layer for processing.
 
-void validate_conn_options( _Inout_ sqlsrv_context& ctx, _In_ zval* user_options_z, _Inout_ char** uid, _Inout_ char** pwd, _Inout_ HashTable* ss_conn_options_ht TSRMLS_DC )
+void validate_conn_options( _Inout_ sqlsrv_context& ctx, _In_ zval* user_options_z, _Inout_ char** uid, _Inout_ char** pwd, _Inout_ HashTable* ss_conn_options_ht )
 {
     try {
 
@@ -1524,7 +1521,7 @@ void validate_conn_options( _Inout_ sqlsrv_context& ctx, _In_ zval* user_options
                     }
                     else {
 
-                        ::add_conn_option_key( ctx, key, key_len, ss_conn_options_ht, data TSRMLS_CC );
+                        ::add_conn_option_key( ctx, key, key_len, ss_conn_options_ht, data );
                     }
                 }
                 else {
