@@ -3,7 +3,7 @@
 //
 // Contents: Core routines that use connection handles shared between sqlsrv and pdo_sqlsrv
 //
-// Microsoft Drivers 5.8 for PHP for SQL Server
+// Microsoft Drivers 5.9 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -68,13 +68,12 @@ const char CONNECTION_OPTION_MARS_ON[] = "MARS_Connection={Yes};";
 
 void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inout_z_ const char* server, _Inout_opt_z_ const char* uid, _Inout_opt_z_ const char* pwd,
                                                 _Inout_opt_ HashTable* options_ht, _In_ const connection_option valid_conn_opts[],
-                                                void* driver,_Inout_ std::string& connection_string TSRMLS_DC );
-void determine_server_version( _Inout_ sqlsrv_conn* conn TSRMLS_DC );
+                                                void* driver,_Inout_ std::string& connection_string );
+void determine_server_version( _Inout_ sqlsrv_conn* conn );
 const char* get_processor_arch( void );
-void get_server_version( _Inout_ sqlsrv_conn* conn, _Outptr_result_buffer_(len) char** server_version, _Out_ SQLSMALLINT& len TSRMLS_DC );
-connection_option const* get_connection_option( sqlsrv_conn* conn, _In_ const char* key, _In_ SQLULEN key_len TSRMLS_DC );
-void common_conn_str_append_func( _In_z_ const char* odbc_name, _In_reads_(val_len) const char* val, _Inout_ size_t val_len, _Inout_ std::string& conn_str TSRMLS_DC );
-void load_azure_key_vault( _Inout_ sqlsrv_conn* conn TSRMLS_DC );
+connection_option const* get_connection_option( sqlsrv_conn* conn, _In_ const char* key, _In_ SQLULEN key_len );
+void common_conn_str_append_func( _In_z_ const char* odbc_name, _In_reads_(val_len) const char* val, _Inout_ size_t val_len, _Inout_ std::string& conn_str );
+void load_azure_key_vault( _Inout_ sqlsrv_conn* conn );
 void configure_azure_key_vault( sqlsrv_conn* conn, BYTE config_attr, const DWORD config_value, size_t key_size);
 void configure_azure_key_vault( sqlsrv_conn* conn, BYTE config_attr, const char* config_value, size_t key_size);
 }
@@ -97,7 +96,7 @@ void configure_azure_key_vault( sqlsrv_conn* conn, BYTE config_attr, const char*
 sqlsrv_conn* core_sqlsrv_connect( _In_ sqlsrv_context& henv_cp, _In_ sqlsrv_context& henv_ncp, _In_ driver_conn_factory conn_factory,
                                   _Inout_z_ const char* server, _Inout_opt_z_ const char* uid, _Inout_opt_z_ const char* pwd,
                                   _Inout_opt_ HashTable* options_ht, _In_ error_callback err, _In_ const connection_option valid_conn_opts[],
-                                  _In_ void* driver, _In_z_ const char* driver_func TSRMLS_DC )
+                                  _In_ void* driver, _In_z_ const char* driver_func )
 
 {
     SQLRETURN r;
@@ -149,11 +148,11 @@ sqlsrv_conn* core_sqlsrv_connect( _In_ sqlsrv_context& henv_cp, _In_ sqlsrv_cont
 #endif // !_WIN32
 
     SQLHANDLE temp_conn_h;
-    core::SQLAllocHandle( SQL_HANDLE_DBC, *henv, &temp_conn_h TSRMLS_CC );
-    conn = conn_factory( temp_conn_h, err, driver TSRMLS_CC );
+    core::SQLAllocHandle( SQL_HANDLE_DBC, *henv, &temp_conn_h );
+    conn = conn_factory( temp_conn_h, err, driver );
     conn->set_func( driver_func );
 
-    build_connection_string_and_set_conn_attr( conn, server, uid, pwd, options_ht, valid_conn_opts, driver, conn_str TSRMLS_CC );
+    build_connection_string_and_set_conn_attr( conn, server, uid, pwd, options_ht, valid_conn_opts, driver, conn_str );
 
     // If column encryption is enabled, must use ODBC driver 17
     if( conn->ce_option.enabled && conn->driver_version != ODBC_DRIVER_UNKNOWN) {
@@ -271,7 +270,7 @@ sqlsrv_conn* core_sqlsrv_connect( _In_ sqlsrv_context& henv_cp, _In_ sqlsrv_cont
 #ifndef _WIN32
     if ( r == SQL_SUCCESS_WITH_INFO ) {
 #endif // !_WIN32
-    determine_server_version( conn TSRMLS_CC );
+    determine_server_version( conn );
 #ifndef _WIN32
     }
 #endif // !_WIN32
@@ -384,6 +383,9 @@ SQLRETURN core_odbc_connect( _Inout_ sqlsrv_conn* conn, _Inout_ std::string& con
     sqlsrv_malloc_auto_ptr<SQLWCHAR> wconn_string;
     unsigned int wconn_len = static_cast<unsigned int>( conn_str.length() + 1 ) * sizeof( SQLWCHAR );
 
+    // Set the desired data classification version before connecting, but older ODBC drivers will generate a warning message 'Driver's SQLSetConnectAttr failed'
+    SQLSetConnectAttr(conn->handle(), SQL_COPT_SS_DATACLASSIFICATION_VERSION, reinterpret_cast<SQLPOINTER>(data_classification::VERSION_RANK_AVAILABLE), SQL_IS_POINTER);
+
     // We only support UTF-8 encoding for connection string.
     // Convert our UTF-8 connection string to UTF-16 before connecting with SQLDriverConnnectW
     wconn_string = utf16_string_from_mbcs_string( SQLSRV_ENCODING_UTF8, conn_str.c_str(), static_cast<unsigned int>( conn_str.length() ), &wconn_len, true );
@@ -426,14 +428,14 @@ SQLRETURN core_odbc_connect( _Inout_ sqlsrv_conn* conn, _Inout_ std::string& con
 // Parameters:
 // sqlsrv_conn*: The connection with which the transaction is associated.
 
-void core_sqlsrv_begin_transaction( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
+void core_sqlsrv_begin_transaction( _Inout_ sqlsrv_conn* conn )
 {
     try {
 
         DEBUG_SQLSRV_ASSERT( conn != NULL, "core_sqlsrv_begin_transaction: connection object was null." );
 
         core::SQLSetConnectAttr( conn, SQL_ATTR_AUTOCOMMIT, reinterpret_cast<SQLPOINTER>( SQL_AUTOCOMMIT_OFF ),
-                                 SQL_IS_UINTEGER TSRMLS_CC );
+                                 SQL_IS_UINTEGER );
     }
     catch ( core::CoreException& ) {
         throw;
@@ -449,16 +451,16 @@ void core_sqlsrv_begin_transaction( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
 // Parameters:
 // sqlsrv_conn*: The connection on which the transaction is active.
 
-void core_sqlsrv_commit( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
+void core_sqlsrv_commit( _Inout_ sqlsrv_conn* conn )
 {
     try {
 
         DEBUG_SQLSRV_ASSERT( conn != NULL, "core_sqlsrv_commit: connection object was null." );
 
-        core::SQLEndTran( SQL_HANDLE_DBC, conn, SQL_COMMIT TSRMLS_CC );
+        core::SQLEndTran( SQL_HANDLE_DBC, conn, SQL_COMMIT );
 
         core::SQLSetConnectAttr( conn, SQL_ATTR_AUTOCOMMIT, reinterpret_cast<SQLPOINTER>( SQL_AUTOCOMMIT_ON ),
-                                SQL_IS_UINTEGER TSRMLS_CC );
+                                SQL_IS_UINTEGER );
     }
     catch ( core::CoreException& ) {
         throw;
@@ -474,16 +476,16 @@ void core_sqlsrv_commit( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
 // Parameters:
 // sqlsrv_conn*: The connection on which the transaction is active.
 
-void core_sqlsrv_rollback( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
+void core_sqlsrv_rollback( _Inout_ sqlsrv_conn* conn )
 {
     try {
 
         DEBUG_SQLSRV_ASSERT( conn != NULL, "core_sqlsrv_rollback: connection object was null." );
 
-        core::SQLEndTran( SQL_HANDLE_DBC, conn, SQL_ROLLBACK TSRMLS_CC );
+        core::SQLEndTran( SQL_HANDLE_DBC, conn, SQL_ROLLBACK );
 
         core::SQLSetConnectAttr( conn, SQL_ATTR_AUTOCOMMIT, reinterpret_cast<SQLPOINTER>( SQL_AUTOCOMMIT_ON ),
-                                 SQL_IS_UINTEGER TSRMLS_CC );
+                                 SQL_IS_UINTEGER );
 
     }
     catch ( core::CoreException& ) {
@@ -495,7 +497,7 @@ void core_sqlsrv_rollback( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
 // Called when a connection resource is destroyed by the Zend engine.
 // Parameters:
 // conn - The current active connection.
-void core_sqlsrv_close( _Inout_opt_ sqlsrv_conn* conn TSRMLS_DC )
+void core_sqlsrv_close( _Inout_opt_ sqlsrv_conn* conn )
 {
     // if the connection wasn't successful, just return.
     if( conn == NULL )
@@ -504,7 +506,7 @@ void core_sqlsrv_close( _Inout_opt_ sqlsrv_conn* conn TSRMLS_DC )
     try {
 
         // rollback any transaction in progress (we don't care about the return result)
-        core::SQLEndTran( SQL_HANDLE_DBC, conn, SQL_ROLLBACK TSRMLS_CC );
+        core::SQLEndTran( SQL_HANDLE_DBC, conn, SQL_ROLLBACK );
     }
     catch( core::CoreException& ) {
         LOG( SEV_ERROR, "Transaction rollback failed when closing the connection." );
@@ -529,7 +531,7 @@ void core_sqlsrv_close( _Inout_opt_ sqlsrv_conn* conn TSRMLS_DC )
 // sql - T-SQL command to prepare
 // sql_len - length of the T-SQL string
 
-void core_sqlsrv_prepare( _Inout_ sqlsrv_stmt* stmt, _In_reads_bytes_(sql_len) const char* sql, _In_ SQLLEN sql_len TSRMLS_DC )
+void core_sqlsrv_prepare( _Inout_ sqlsrv_stmt* stmt, _In_reads_bytes_(sql_len) const char* sql, _In_ SQLLEN sql_len )
 {
     try {
 
@@ -557,7 +559,7 @@ void core_sqlsrv_prepare( _Inout_ sqlsrv_stmt* stmt, _In_reads_bytes_(sql_len) c
         }
 
         // prepare our wide char query string
-        core::SQLPrepareW( stmt, reinterpret_cast<SQLWCHAR*>( wsql_string.get() ), wsql_len TSRMLS_CC );
+        core::SQLPrepareW( stmt, reinterpret_cast<SQLWCHAR*>( wsql_string.get() ), wsql_len );
 
         stmt->param_descriptions.clear();
 
@@ -587,22 +589,14 @@ void core_sqlsrv_prepare( _Inout_ sqlsrv_stmt* stmt, _In_reads_bytes_(sql_len) c
 // conn             - The connection resource by which the client and server are connected.
 // *server_version  - zval for returning results.
 
-void core_sqlsrv_get_server_version( _Inout_ sqlsrv_conn* conn, _Inout_ zval* server_version TSRMLS_DC )
+void core_sqlsrv_get_server_version( _Inout_ sqlsrv_conn* conn, _Inout_ zval* server_version )
 {
     try {
-
-        sqlsrv_malloc_auto_ptr<char> buffer;
+        char buffer[INFO_BUFFER_LEN] = "";
         SQLSMALLINT buffer_len = 0;
-
-        get_server_version( conn, &buffer, buffer_len TSRMLS_CC );
-        core::sqlsrv_zval_stringl( server_version, buffer, buffer_len );
-        if ( buffer != 0 ) {
-            sqlsrv_free( buffer );
-        }
-        buffer.transferred();
-    }
-
-    catch( core::CoreException& ) {
+        core::SQLGetInfo(conn, SQL_DBMS_VER, buffer, INFO_BUFFER_LEN, &buffer_len);
+        core::sqlsrv_zval_stringl(server_version, buffer, buffer_len);
+    } catch( core::CoreException& ) {
         throw;
     }
 }
@@ -614,36 +608,28 @@ void core_sqlsrv_get_server_version( _Inout_ sqlsrv_conn* conn, _Inout_ zval* se
 // conn         - The connection resource by which the client and server are connected.
 // *server_info - zval for returning results.
 
-void core_sqlsrv_get_server_info( _Inout_ sqlsrv_conn* conn, _Out_ zval *server_info TSRMLS_DC )
+void core_sqlsrv_get_server_info( _Inout_ sqlsrv_conn* conn, _Out_ zval *server_info )
 {
     try {
-
-        sqlsrv_malloc_auto_ptr<char> buffer;
+        char buffer[INFO_BUFFER_LEN] = "";
         SQLSMALLINT buffer_len = 0;
 
         // Get the database name
-        buffer = static_cast<char*>( sqlsrv_malloc( INFO_BUFFER_LEN ));
-        core::SQLGetInfo( conn, SQL_DATABASE_NAME, buffer, INFO_BUFFER_LEN, &buffer_len TSRMLS_CC );
+        core::SQLGetInfo(conn, SQL_DATABASE_NAME, buffer, INFO_BUFFER_LEN, &buffer_len);
 
         // initialize the array
-        core::sqlsrv_array_init( *conn, server_info TSRMLS_CC );
+        array_init(server_info);
 
-        core::sqlsrv_add_assoc_string( *conn, server_info, "CurrentDatabase", buffer, 0 /*duplicate*/ TSRMLS_CC );
-        buffer.transferred();
+        add_assoc_string(server_info, "CurrentDatabase", buffer);
 
         // Get the server version
-        get_server_version( conn, &buffer, buffer_len TSRMLS_CC );
-        core::sqlsrv_add_assoc_string( *conn, server_info, "SQLServerVersion", buffer, 0 /*duplicate*/ TSRMLS_CC );
-        buffer.transferred();
+        core::SQLGetInfo(conn, SQL_DBMS_VER, buffer, INFO_BUFFER_LEN, &buffer_len);
+        add_assoc_string(server_info, "SQLServerVersion", buffer);
 
         // Get the server name
-        buffer = static_cast<char*>( sqlsrv_malloc( INFO_BUFFER_LEN ));
-        core::SQLGetInfo( conn, SQL_SERVER_NAME, buffer, INFO_BUFFER_LEN, &buffer_len TSRMLS_CC );
-        core::sqlsrv_add_assoc_string( *conn, server_info, "SQLServerName", buffer, 0 /*duplicate*/ TSRMLS_CC );
-        buffer.transferred();
-    }
-
-    catch( core::CoreException& ) {
+        core::SQLGetInfo(conn, SQL_SERVER_NAME, buffer, INFO_BUFFER_LEN, &buffer_len);
+        add_assoc_string(server_info, "SQLServerName", buffer);
+    } catch (core::CoreException&) {
         throw;
     }
 }
@@ -654,42 +640,32 @@ void core_sqlsrv_get_server_info( _Inout_ sqlsrv_conn* conn, _Out_ zval *server_
 // conn         - The connection resource by which the client and server are connected.
 // *client_info - zval for returning the results.
 
-void core_sqlsrv_get_client_info( _Inout_ sqlsrv_conn* conn, _Out_ zval *client_info TSRMLS_DC )
+void core_sqlsrv_get_client_info( _Inout_ sqlsrv_conn* conn, _Out_ zval *client_info )
 {
     try {
-
-        sqlsrv_malloc_auto_ptr<char> buffer;
+        char buffer[INFO_BUFFER_LEN] = "";
         SQLSMALLINT buffer_len = 0;
 
         // Get the ODBC driver's dll name
-        buffer = static_cast<char*>( sqlsrv_malloc( INFO_BUFFER_LEN ));
-        core::SQLGetInfo( conn, SQL_DRIVER_NAME, buffer, INFO_BUFFER_LEN, &buffer_len TSRMLS_CC );
+        core::SQLGetInfo( conn, SQL_DRIVER_NAME, buffer, INFO_BUFFER_LEN, &buffer_len );
 
         // initialize the array
-        core::sqlsrv_array_init( *conn, client_info TSRMLS_CC );
+        array_init(client_info);
 
 #ifndef _WIN32
-        core::sqlsrv_add_assoc_string( *conn, client_info, "DriverName", buffer, 0 /*duplicate*/ TSRMLS_CC );
+        add_assoc_string(client_info, "DriverName", buffer);
 #else
-        core::sqlsrv_add_assoc_string( *conn, client_info, "DriverDllName", buffer, 0 /*duplicate*/ TSRMLS_CC );
+        add_assoc_string(client_info, "DriverDllName", buffer);
 #endif // !_WIN32
-        buffer.transferred();
 
         // Get the ODBC driver's ODBC version
-        buffer = static_cast<char*>( sqlsrv_malloc( INFO_BUFFER_LEN ));
-        core::SQLGetInfo( conn, SQL_DRIVER_ODBC_VER, buffer, INFO_BUFFER_LEN, &buffer_len TSRMLS_CC );
-        core::sqlsrv_add_assoc_string( *conn, client_info, "DriverODBCVer", buffer, 0 /*duplicate*/ TSRMLS_CC );
-        buffer.transferred();
+        core::SQLGetInfo( conn, SQL_DRIVER_ODBC_VER, buffer, INFO_BUFFER_LEN, &buffer_len );
+        add_assoc_string(client_info, "DriverODBCVer", buffer);
 
         // Get the OBDC driver's version
-        buffer = static_cast<char*>( sqlsrv_malloc( INFO_BUFFER_LEN ));
-        core::SQLGetInfo( conn, SQL_DRIVER_VER, buffer, INFO_BUFFER_LEN, &buffer_len TSRMLS_CC );
-        core::sqlsrv_add_assoc_string( *conn, client_info, "DriverVer", buffer, 0 /*duplicate*/ TSRMLS_CC );
-        buffer.transferred();
-
-    }
-
-    catch( core::CoreException& ) {
+        core::SQLGetInfo( conn, SQL_DRIVER_VER, buffer, INFO_BUFFER_LEN, &buffer_len );
+        add_assoc_string(client_info, "DriverVer", buffer);
+    } catch( core::CoreException& ) {
         throw;
     }
 }
@@ -733,18 +709,38 @@ bool core_is_conn_opt_value_escaped( _Inout_ const char* value, _Inout_ size_t v
     return true;
 }
 
-// core_is_authentication_option_valid
-// if the option for the authentication is valid, returns true. This returns false otherwise.
-bool core_is_authentication_option_valid( _In_z_ const char* value, _In_ size_t value_len)
-{
-    if (value_len <= 0)
-        return false;
+namespace AzureADOptions {
+    enum AAD_AUTH_TYPE {
+        MIN_AAD_AUTH_TYPE = 0,
+        SQL_PASSWORD = 0,
+        AAD_PASSWORD,
+        AAD_MSI,
+        AAD_SPA,
+        MAX_AAD_AUTH_TYPE
+    };
 
-    if (!stricmp(value, AzureADOptions::AZURE_AUTH_SQL_PASSWORD) || !stricmp(value, AzureADOptions::AZURE_AUTH_AD_PASSWORD) || !stricmp(value, AzureADOptions::AZURE_AUTH_AD_MSI)) {
-        return true;
+    const char *AADAuths[] = { "SqlPassword", "ActiveDirectoryPassword", "ActiveDirectoryMsi", "ActiveDirectoryServicePrincipal" };
+
+    bool isAuthValid(_In_z_ const char* value, _In_ size_t value_len)
+    {
+        if (value_len <= 0)
+            return false;
+
+        bool isValid = false;
+        for (short i = MIN_AAD_AUTH_TYPE; i < MAX_AAD_AUTH_TYPE && !isValid; i++)
+        {
+            if (!stricmp(value, AADAuths[i])) {
+                isValid = true;
+            }
+        }
+
+        return isValid;
     }
 
-    return false;
+    bool isAADMsi(_In_z_ const char* value)
+    {
+        return (value != NULL && !stricmp(value, AADAuths[AAD_MSI]));
+    }
 }
 
 
@@ -753,7 +749,7 @@ bool core_is_authentication_option_valid( _In_z_ const char* value, _In_ size_t
 namespace {
 
 connection_option const* get_connection_option( sqlsrv_conn* conn, _In_ SQLULEN key,
-                                                     _In_ const connection_option conn_opts[] TSRMLS_DC )
+                                                     _In_ const connection_option conn_opts[] )
 {
     for( int opt_idx = 0; conn_opts[opt_idx].conn_option_key != SQLSRV_CONN_OPTION_INVALID; ++opt_idx ) {
 
@@ -774,7 +770,7 @@ connection_option const* get_connection_option( sqlsrv_conn* conn, _In_ SQLULEN
 
 void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inout_z_ const char* server, _Inout_opt_z_  const char* uid, _Inout_opt_z_ const char* pwd,
                                                 _Inout_opt_ HashTable* options, _In_ const connection_option valid_conn_opts[],
-                                                void* driver, _Inout_ std::string& connection_string TSRMLS_DC )
+                                                void* driver, _Inout_ std::string& connection_string )
 {
     bool mars_mentioned = false;
     connection_option const* conn_opt;
@@ -808,11 +804,14 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
             zval* auth_option = NULL;
             auth_option = zend_hash_index_find(options, SQLSRV_CONN_OPTION_AUTHENTICATION);
 
-            char* option = Z_STRVAL_P(auth_option);
-
-            if (!stricmp(option, AzureADOptions::AZURE_AUTH_AD_MSI)) {
-                activeDirectoryMSI = true;
+            char* option = NULL;
+            if (auth_option != NULL) {
+                option = Z_STRVAL_P(auth_option);
+            }
 
+            //if (option != NULL && !stricmp(option, AzureADOptions::AZURE_AUTH_AD_MSI)) {
+            activeDirectoryMSI = AzureADOptions::isAADMsi(option);
+            if (activeDirectoryMSI) {
                 // There are two types of managed identities:
                 // (1) A system-assigned managed identity: UID must be NULL
                 // (2) A user-assigned managed identity: UID defined but must not be an empty string
@@ -834,7 +833,7 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
         }
 
         // Add the server name
-        common_conn_str_append_func( ODBCConnOptions::SERVER, server, strnlen_s( server ), connection_string TSRMLS_CC );
+        common_conn_str_append_func( ODBCConnOptions::SERVER, server, strnlen_s( server ), connection_string );
 
         // If uid is not present then we use trusted connection -- but not when access token or ActiveDirectoryMSI is used,
         // because they are incompatible
@@ -848,7 +847,7 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
                     throw core::CoreException();
                 }
 
-                common_conn_str_append_func(ODBCConnOptions::UID, uid, strnlen_s(uid), connection_string TSRMLS_CC);
+                common_conn_str_append_func(ODBCConnOptions::UID, uid, strnlen_s(uid), connection_string);
 
                 // if no password was given, then don't add a password to the connection string.  Perhaps the UID
                 // given doesn't have a password?
@@ -858,7 +857,7 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
                         throw core::CoreException();
                     }
 
-                    common_conn_str_append_func(ODBCConnOptions::PWD, pwd, strnlen_s(pwd), connection_string TSRMLS_CC);
+                    common_conn_str_append_func(ODBCConnOptions::PWD, pwd, strnlen_s(pwd), connection_string);
                 }
             }
         }
@@ -894,13 +893,13 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
             // The driver layer should ensure a valid key.
             DEBUG_SQLSRV_ASSERT(( type == HASH_KEY_IS_LONG ), "build_connection_string_and_set_conn_attr: invalid connection option key type." );
 
-            conn_opt = get_connection_option( conn, index, valid_conn_opts TSRMLS_CC );
+            conn_opt = get_connection_option( conn, index, valid_conn_opts );
 
             if( index == SQLSRV_CONN_OPTION_MARS ) {
                 mars_mentioned = true;
             }
 
-            conn_opt->func( conn_opt, data, conn, connection_string TSRMLS_CC );
+            conn_opt->func( conn_opt, data, conn, connection_string );
         } ZEND_HASH_FOREACH_END();
 
         // MARS on if not explicitly turned off
@@ -915,30 +914,6 @@ void build_connection_string_and_set_conn_attr( _Inout_ sqlsrv_conn* conn, _Inou
     }
 }
 
-
-// get_server_version
-// Helper function which returns the version of the SQL Server we are connected to.
-
-void get_server_version( _Inout_ sqlsrv_conn* conn, _Outptr_result_buffer_(len) char** server_version, _Out_ SQLSMALLINT& len TSRMLS_DC )
-{
-    try {
-
-        sqlsrv_malloc_auto_ptr<char> buffer;
-        SQLSMALLINT buffer_len = 0;
-
-        buffer = static_cast<char*>( sqlsrv_malloc( INFO_BUFFER_LEN ));
-        core::SQLGetInfo( conn, SQL_DBMS_VER, buffer, INFO_BUFFER_LEN, &buffer_len TSRMLS_CC );
-        *server_version = buffer;
-        len = buffer_len;
-        buffer.transferred();
-    }
-
-    catch( core::CoreException& ) {
-        throw;
-    }
-}
-
-
 // get_processor_arch
 // Calls GetSystemInfo to verify the what architecture of the processor is supported
 // and return the string of the processor name.
@@ -989,11 +964,11 @@ const char* get_processor_arch( void )
 // Exception is thrown when the server version is either undetermined
 // or is invalid (< 2000).
 
-void determine_server_version( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
+void determine_server_version( _Inout_ sqlsrv_conn* conn )
 {
     SQLSMALLINT info_len;
     char p[INFO_BUFFER_LEN] = {'\0'};
-    core::SQLGetInfo( conn, SQL_DBMS_VER, p, INFO_BUFFER_LEN, &info_len TSRMLS_CC );
+    core::SQLGetInfo( conn, SQL_DBMS_VER, p, INFO_BUFFER_LEN, &info_len );
 
     errno = 0;
     char version_major_str[3] = {'\0'};
@@ -1013,7 +988,7 @@ void determine_server_version( _Inout_ sqlsrv_conn* conn TSRMLS_DC )
     conn->server_version = version_major;
 }
 
-void load_azure_key_vault(_Inout_ sqlsrv_conn* conn TSRMLS_DC)
+void load_azure_key_vault(_Inout_ sqlsrv_conn* conn)
 {
     // If column encryption is not enabled simply do nothing. Otherwise, check if Azure Key Vault
     // is required for encryption or decryption. Note, in order to load and configure Azure Key Vault,
@@ -1092,11 +1067,10 @@ void configure_azure_key_vault(sqlsrv_conn* conn, BYTE config_attr, const char*
     core::SQLSetConnectAttr(conn, SQL_COPT_SS_CEKEYSTOREDATA, reinterpret_cast<SQLPOINTER>(pData), SQL_IS_POINTER);
 }
 
-void common_conn_str_append_func( _In_z_ const char* odbc_name, _In_reads_(val_len) const char* val, _Inout_ size_t val_len, _Inout_ std::string& conn_str TSRMLS_DC )
+void common_conn_str_append_func( _In_z_ const char* odbc_name, _In_reads_(val_len) const char* val, _Inout_ size_t val_len, _Inout_ std::string& conn_str )
 {
     // wrap a connection option in a quote.  It is presumed that any character that need to be escaped will
     // be escaped, such as a closing }.
-    TSRMLS_C;
 
     if( val_len > 0 && val[0] == '{' && val[val_len - 1] == '}' ) {
         ++val;
@@ -1111,26 +1085,25 @@ void common_conn_str_append_func( _In_z_ const char* odbc_name, _In_reads_(val_l
 }   // namespace
 
 // simply add the parsed value to the connection string
-void conn_str_append_func::func( _In_ connection_option const* option, _In_ zval* value, sqlsrv_conn* /*conn*/, _Inout_ std::string& conn_str TSRMLS_DC )
+void conn_str_append_func::func( _In_ connection_option const* option, _In_ zval* value, sqlsrv_conn* /*conn*/, _Inout_ std::string& conn_str )
 {
     const char* val_str = Z_STRVAL_P( value );
     size_t val_len = Z_STRLEN_P( value );
-    common_conn_str_append_func( option->odbc_name, val_str, val_len, conn_str TSRMLS_CC );
+    common_conn_str_append_func( option->odbc_name, val_str, val_len, conn_str );
 }
 
 // do nothing for connection pooling since we handled it earlier when
 // deciding which environment handle to use.
-void conn_null_func::func( connection_option const* /*option*/, zval* /*value*/, sqlsrv_conn* /*conn*/, std::string& /*conn_str*/ TSRMLS_DC )
+void conn_null_func::func( connection_option const* /*option*/, zval* /*value*/, sqlsrv_conn* /*conn*/, std::string& /*conn_str*/ )
 {
-    TSRMLS_C;
 }
 
-void driver_set_func::func( _In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str TSRMLS_DC )
+void driver_set_func::func( _In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str )
 {
     const char* val_str = Z_STRVAL_P( value );
     size_t val_len = Z_STRLEN_P( value );
     std::string driver_option( "" );
-    common_conn_str_append_func( option->odbc_name, val_str, val_len, driver_option TSRMLS_CC );
+    common_conn_str_append_func( option->odbc_name, val_str, val_len, driver_option );
 
     conn->driver_version = ODBC_DRIVER_UNKNOWN;
     for ( short i = DRIVER_VERSION::FIRST; i <= DRIVER_VERSION::LAST && conn->driver_version == ODBC_DRIVER_UNKNOWN; ++i ) {
@@ -1148,7 +1121,7 @@ void driver_set_func::func( _In_ connection_option const* option, _In_ zval* val
     conn_str += driver_option;
 }
 
-void column_encryption_set_func::func( _In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str TSRMLS_DC )
+void column_encryption_set_func::func( _In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str )
 {
     convert_to_string( value );
     const char* value_str = Z_STRVAL_P( value );
@@ -1168,7 +1141,7 @@ void column_encryption_set_func::func( _In_ connection_option const* option, _In
     conn_str += ";";
 }
 
-void ce_akv_str_set_func::func(_In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str TSRMLS_DC)
+void ce_akv_str_set_func::func(_In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str)
 {
     SQLSRV_ASSERT(Z_TYPE_P(value) == IS_STRING, "Azure Key Vault keywords accept only strings.");
 
@@ -1254,7 +1227,7 @@ size_t core_str_zval_is_true( _Inout_ zval* value_z )
     return 0; // false
 }
 
-void access_token_set_func::func( _In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str TSRMLS_DC )
+void access_token_set_func::func( _In_ connection_option const* option, _In_ zval* value, _Inout_ sqlsrv_conn* conn, _Inout_ std::string& conn_str )
 {
     SQLSRV_ASSERT(Z_TYPE_P(value) == IS_STRING, "An access token must be a byte string.");
 
