@@ -3,7 +3,7 @@
 //
 // Contents: Result sets
 //
-// Microsoft Drivers 5.8 for PHP for SQL Server
+// Microsoft Drivers 5.9 for PHP for SQL Server
 // Copyright(c) Microsoft Corporation
 // All rights reserved.
 // MIT License
@@ -78,7 +78,7 @@ bool get_bit( _In_ void* ptr, _In_ unsigned int bit )
 
 // read in LOB field during buffered result creation
 SQLPOINTER read_lob_field( _Inout_ sqlsrv_stmt* stmt, _In_ SQLUSMALLINT field_index, _In_ sqlsrv_buffered_result_set::meta_data& meta,
-                           _In_ zend_long mem_used TSRMLS_DC );
+                           _In_ zend_long mem_used );
 
 // dtor for each row in the cache
 void cache_row_dtor( _In_ zval* data );
@@ -262,64 +262,6 @@ std::string getUTF8StringFromString( _In_z_ const char* source )
 
 #endif // !_WIN32
 
-template <typename Number, typename Char>
-SQLRETURN string_to_number( _In_z_ Char* string_data, SQLLEN str_len, _Out_writes_bytes_(*out_buffer_length) void* buffer, SQLLEN buffer_length,
-                            _Inout_ SQLLEN* out_buffer_length, _Inout_ sqlsrv_error_auto_ptr& last_error )
-{
-    Number* number_data = reinterpret_cast<Number*>( buffer ); 
-#ifdef _WIN32
-    std::locale loc;    // default locale should match system
-    std::basic_istringstream<Char> is;
-    is.str( string_data );
-    is.imbue( loc );
-    std::ios_base::iostate st = 0;
-
-    std::use_facet< std::num_get< Char > >( loc ).get( std::basic_istream<Char>::_Iter( is.rdbuf()), std::basic_istream<Char>::_Iter( 0 ), is, st, *number_data );
-
-    if ( st & std::ios_base::failbit ) {
-        last_error = new ( sqlsrv_malloc( sizeof( sqlsrv_error ))) sqlsrv_error(( SQLCHAR* ) "22003", ( SQLCHAR* ) "Numeric value out of range", 103 );
-        return SQL_ERROR;
-    }
-
-    *out_buffer_length = sizeof( Number );
-#else
-    std::string str = getUTF8StringFromString( string_data );
-
-    std::istringstream is( str );
-    std::locale loc;    // default locale should match system
-    is.imbue( loc );
-
-    auto& facet = std::use_facet<std::num_get<char>>( is.getloc() );
-    std::istreambuf_iterator<char> beg( is ), end;
-    std::ios_base::iostate err = std::ios_base::goodbit;
-
-    if ( std::is_integral<Number>::value )
-    {
-        long number;
-        facet.get( beg, end, is, err, number );
-
-        *number_data = number;
-    }
-    else
-    {
-        double number;
-        facet.get( beg, end, is, err, number );
-
-        *number_data = number;
-    }
-
-    *out_buffer_length = sizeof( Number );
-
-    if ( is.fail() )
-    {
-        last_error = new ( sqlsrv_malloc(sizeof( sqlsrv_error ))) sqlsrv_error(( SQLCHAR* ) "22003", ( SQLCHAR* ) "Numeric value out of range", 103 );
-        return SQL_ERROR;
-    }
-#endif // _WIN32
-    return SQL_SUCCESS;
-  
-}
-
 // "closure" for the hash table destructor
 struct row_dtor_closure {
 
@@ -391,27 +333,27 @@ sqlsrv_odbc_result_set::~sqlsrv_odbc_result_set( void )
 {
 }
 
-SQLRETURN sqlsrv_odbc_result_set::fetch( _In_ SQLSMALLINT orientation, _In_ SQLLEN offset TSRMLS_DC )
+SQLRETURN sqlsrv_odbc_result_set::fetch( _In_ SQLSMALLINT orientation, _In_ SQLLEN offset )
 {
     SQLSRV_ASSERT( odbc != NULL, "Invalid statement handle" );
-    return core::SQLFetchScroll( odbc, orientation, offset TSRMLS_CC );
+    return core::SQLFetchScroll( odbc, orientation, offset );
 }
 
 SQLRETURN sqlsrv_odbc_result_set::get_data( _In_ SQLUSMALLINT field_index, _In_ SQLSMALLINT target_type,
                                             _Out_writes_opt_(buffer_length) SQLPOINTER buffer, _In_ SQLLEN buffer_length, _Inout_ SQLLEN* out_buffer_length,
-                                            _In_ bool handle_warning TSRMLS_DC )
+                                            _In_ bool handle_warning )
 {
     SQLSRV_ASSERT( odbc != NULL, "Invalid statement handle" );
-    return core::SQLGetData( odbc, field_index, target_type, buffer, buffer_length, out_buffer_length, handle_warning TSRMLS_CC );
+    return core::SQLGetData( odbc, field_index, target_type, buffer, buffer_length, out_buffer_length, handle_warning );
 }
 
 SQLRETURN sqlsrv_odbc_result_set::get_diag_field( _In_ SQLSMALLINT record_number, _In_ SQLSMALLINT diag_identifier, 
                                                   _Inout_updates_(buffer_length) SQLPOINTER diag_info_buffer, _In_ SQLSMALLINT buffer_length,
-                                                  _Inout_ SQLSMALLINT* out_buffer_length TSRMLS_DC )
+                                                  _Inout_ SQLSMALLINT* out_buffer_length )
 {
     SQLSRV_ASSERT( odbc != NULL, "Invalid statement handle" );
     return core::SQLGetDiagField( odbc, record_number, diag_identifier, diag_info_buffer, buffer_length, 
-                                  out_buffer_length TSRMLS_CC );
+                                  out_buffer_length );
 }
 
 sqlsrv_error* sqlsrv_odbc_result_set::get_diag_rec( _In_ SQLSMALLINT record_number )
@@ -420,17 +362,17 @@ sqlsrv_error* sqlsrv_odbc_result_set::get_diag_rec( _In_ SQLSMALLINT record_numb
     return odbc_get_diag_rec( odbc, record_number );
 }
 
-SQLLEN sqlsrv_odbc_result_set::row_count( TSRMLS_D )
+SQLLEN sqlsrv_odbc_result_set::row_count( void )
 {
     SQLSRV_ASSERT( odbc != NULL, "Invalid statement handle" );
-    return core::SQLRowCount( odbc TSRMLS_CC );
+    return core::SQLRowCount( odbc );
 }
 
 
 // Buffered result set
 // This class holds a result set in memory
 
-sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stmt TSRMLS_DC ) :
+sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stmt ) :
     sqlsrv_result_set( stmt ),
     cache(NULL),
     col_count(0),
@@ -439,7 +381,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
     read_so_far(0),
     temp_length(0)
 {
-    col_count = core::SQLNumResultCols( stmt TSRMLS_CC );
+    col_count = core::SQLNumResultCols( stmt );
     // there is no result set to buffer
     if( col_count == 0 ) {
         return;
@@ -456,7 +398,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
     SQLULEN offset = null_bytes;
     for( SQLSMALLINT i = 0; i < col_count; ++i ) {
 				
-        core::SQLDescribeColW( stmt, i + 1, NULL, 0, NULL, &meta[i].type, &meta[i].length, &meta[i].scale, NULL TSRMLS_CC );
+        core::SQLDescribeColW( stmt, i + 1, NULL, 0, NULL, &meta[i].type, &meta[i].length, &meta[i].scale, NULL );
 
         offset = align_to<sizeof(SQLPOINTER)>( offset );
         meta[i].offset = offset;
@@ -469,7 +411,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
             case SQL_GUID:
             case SQL_NUMERIC:
                 core::SQLColAttributeW( stmt, i + 1, SQL_DESC_DISPLAY_SIZE, NULL, 0, NULL,
-                                       reinterpret_cast<SQLLEN*>( &meta[i].length ) TSRMLS_CC );
+                                       reinterpret_cast<SQLLEN*>( &meta[i].length ) );
                 meta[i].length += sizeof( char ) + sizeof( SQLULEN ); // null terminator space
                 offset += meta[i].length;
                 break;
@@ -536,7 +478,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
             case SQL_SS_TIMESTAMPOFFSET:
             case SQL_TYPE_TIMESTAMP:
                 core::SQLColAttributeW( stmt, i + 1, SQL_DESC_DISPLAY_SIZE, NULL, 0, NULL, 
-                                       reinterpret_cast<SQLLEN*>( &meta[i].length ) TSRMLS_CC );
+                                       reinterpret_cast<SQLLEN*>( &meta[i].length ) );
                 meta[i].length += sizeof(char) + sizeof( SQLULEN );  // null terminator space
                 offset += meta[i].length;
                 break;
@@ -628,10 +570,10 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
     size_t row_count = 0;
     // 10 is an arbitrary number for now for the initial size of the cache
     ALLOC_HASHTABLE( cache );
-    core::sqlsrv_zend_hash_init( *stmt, cache, 10 /* # of buckets */, cache_row_dtor /*dtor*/, 0 /*persistent*/ TSRMLS_CC );
+    core::sqlsrv_zend_hash_init( *stmt, cache, 10 /* # of buckets */, cache_row_dtor /*dtor*/, 0 /*persistent*/ );
 
     try {
-        while( core::SQLFetchScroll( stmt, SQL_FETCH_NEXT, 0 TSRMLS_CC ) != SQL_NO_DATA ) {
+        while( core::SQLFetchScroll( stmt, SQL_FETCH_NEXT, 0 ) != SQL_NO_DATA ) {
             
             // allocate the row buffer
             sqlsrv_malloc_auto_ptr<unsigned char> rowAuto;
@@ -655,7 +597,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
 
                             out_buffer_length = &out_buffer_temp;
                             SQLPOINTER* lob_addr = reinterpret_cast<SQLPOINTER*>( &row[meta[i].offset] );
-                            *lob_addr = read_lob_field( stmt, i, meta[i], mem_used TSRMLS_CC );
+                            *lob_addr = read_lob_field( stmt, i, meta[i], mem_used );
                             // a NULL pointer means NULL field
                             if( *lob_addr == NULL ) {
                                 *out_buffer_length = SQL_NULL_DATA;
@@ -677,7 +619,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
                             buffer = row + meta[i].offset + sizeof( SQLULEN );
                             out_buffer_length = reinterpret_cast<SQLLEN*>( row + meta[i].offset );
                             core::SQLGetData( stmt, i + 1, meta[i].c_type, buffer, meta[i].length, out_buffer_length, 
-                                              false TSRMLS_CC );
+                                              false );
                         }
                         break;
 
@@ -693,7 +635,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
                             buffer = row + meta[i].offset;
                             out_buffer_length = &out_buffer_temp;
                             core::SQLGetData( stmt, i + 1, meta[i].c_type, buffer, meta[i].length, out_buffer_length, 
-                                              false TSRMLS_CC );
+                                              false );
                         }
                         break;                        
 
@@ -712,7 +654,7 @@ sqlsrv_buffered_result_set::sqlsrv_buffered_result_set( _Inout_ sqlsrv_stmt* stm
 
             // add it to the cache
             row_dtor_closure cl( this, row );
-            sqlsrv_zend_hash_next_index_insert_mem( *stmt, cache, &cl, sizeof(row_dtor_closure) TSRMLS_CC );
+            sqlsrv_zend_hash_next_index_insert_mem( *stmt, cache, &cl, sizeof(row_dtor_closure) );
             rowAuto.transferred();
         }   
     } 
@@ -738,7 +680,7 @@ sqlsrv_buffered_result_set::~sqlsrv_buffered_result_set( void )
     }
 }
 
-SQLRETURN sqlsrv_buffered_result_set::fetch( _Inout_ SQLSMALLINT orientation, _Inout_opt_ SQLLEN offset TSRMLS_DC )
+SQLRETURN sqlsrv_buffered_result_set::fetch( _Inout_ SQLSMALLINT orientation, _Inout_opt_ SQLLEN offset )
 {
     last_error = NULL;
     last_field_index = -1;
@@ -762,7 +704,7 @@ SQLRETURN sqlsrv_buffered_result_set::fetch( _Inout_ SQLSMALLINT orientation, _I
             current = 1;
             break;
         case SQL_FETCH_LAST:
-            current = row_count( TSRMLS_C );
+            current = row_count();
             break;
         case SQL_FETCH_ABSOLUTE:
             current = offset;
@@ -783,8 +725,8 @@ SQLRETURN sqlsrv_buffered_result_set::fetch( _Inout_ SQLSMALLINT orientation, _I
     }
 
     // the cursor can never get further away than just after the last row
-    if( current > row_count( TSRMLS_C ) || ( current <= 0 && offset > 0 ) /*overflow condition*/ ) {
-        current = row_count( TSRMLS_C ) + 1;
+    if( current > row_count() || ( current <= 0 && offset > 0 ) /*overflow condition*/ ) {
+        current = row_count() + 1;
         return SQL_NO_DATA;
     }
 
@@ -793,7 +735,7 @@ SQLRETURN sqlsrv_buffered_result_set::fetch( _Inout_ SQLSMALLINT orientation, _I
 
 SQLRETURN sqlsrv_buffered_result_set::get_data( _In_ SQLUSMALLINT field_index, _In_ SQLSMALLINT target_type,
                                                 _Out_writes_bytes_opt_(buffer_length) SQLPOINTER buffer, _In_ SQLLEN buffer_length, _Inout_ SQLLEN* out_buffer_length,
-                                                bool handle_warning TSRMLS_DC )
+                                                bool handle_warning )
 {
     last_error = NULL;
     field_index--;      // convert from 1 based to 0 based
@@ -851,7 +793,6 @@ SQLRETURN sqlsrv_buffered_result_set::get_data( _In_ SQLUSMALLINT field_index, _
         case SQL_C_LONG: return sqlsrv_buffered_result_set::to_long(field_index, buffer, buffer_length, out_buffer_length);
         case SQL_C_BINARY: return sqlsrv_buffered_result_set::to_long(field_index, buffer, buffer_length, out_buffer_length);
         case SQL_C_CHAR: return sqlsrv_buffered_result_set::long_to_system_string(field_index, buffer, buffer_length, out_buffer_length);
-        case SQL_C_WCHAR: return sqlsrv_buffered_result_set::long_to_wide_string(field_index, buffer, buffer_length, out_buffer_length);
         default:
             break;
         }
@@ -862,7 +803,6 @@ SQLRETURN sqlsrv_buffered_result_set::get_data( _In_ SQLUSMALLINT field_index, _
         case SQL_C_BINARY: return sqlsrv_buffered_result_set::to_double(field_index, buffer, buffer_length, out_buffer_length);
         case SQL_C_CHAR: return sqlsrv_buffered_result_set::double_to_system_string(field_index, buffer, buffer_length, out_buffer_length);
         case SQL_C_LONG: return sqlsrv_buffered_result_set::double_to_long(field_index, buffer, buffer_length, out_buffer_length);
-        case SQL_C_WCHAR: return sqlsrv_buffered_result_set::double_to_wide_string(field_index, buffer, buffer_length, out_buffer_length);
         default:
             break;
         }
@@ -879,7 +819,7 @@ SQLRETURN sqlsrv_buffered_result_set::get_data( _In_ SQLUSMALLINT field_index, _
 
 SQLRETURN sqlsrv_buffered_result_set::get_diag_field( _In_ SQLSMALLINT record_number, _In_ SQLSMALLINT diag_identifier, 
                                                       _Inout_updates_(buffer_length) SQLPOINTER diag_info_buffer, _In_ SQLSMALLINT buffer_length,
-                                                      _Inout_ SQLSMALLINT* out_buffer_length TSRMLS_DC )
+                                                      _Inout_ SQLSMALLINT* out_buffer_length )
 {
     SQLSRV_ASSERT( record_number == 1, "Only record number 1 can be fetched by sqlsrv_buffered_result_set::get_diag_field" );
     SQLSRV_ASSERT( diag_identifier == SQL_DIAG_SQLSTATE, 
@@ -923,7 +863,7 @@ sqlsrv_error* sqlsrv_buffered_result_set::get_diag_rec( _In_ SQLSMALLINT record_
         sqlsrv_error( last_error->sqlstate, last_error->native_message, last_error->native_code );
 }
 
-SQLLEN sqlsrv_buffered_result_set::row_count( TSRMLS_D )
+SQLLEN sqlsrv_buffered_result_set::row_count( void )
 {
     last_error = NULL;
 
@@ -942,7 +882,7 @@ SQLRETURN binary_to_string( _Inout_ SQLCHAR* field_data, _Inout_ SQLLEN& read_so
                                                         _In_ SQLLEN buffer_length, _Inout_ SQLLEN* out_buffer_length, 
                                                         _Inout_ sqlsrv_error_auto_ptr& out_error )
 {
-    // hex characters for the conversion loop below
+    // The hex characters for the conversion loop below
     static char hex_chars[] = "0123456789ABCDEF";
 
     SQLSRV_ASSERT( out_error == 0, "Pending error for sqlsrv_buffered_results_set::binary_to_string" );
@@ -952,17 +892,19 @@ SQLRETURN binary_to_string( _Inout_ SQLCHAR* field_data, _Inout_ SQLLEN& read_so
     // Set the amount of space necessary for null characters at the end of the data.
     SQLSMALLINT extra = sizeof(Char);
 
-    SQLSRV_ASSERT( ((buffer_length - extra) % (extra * 2)) == 0, "Must be multiple of 2 for binary to system string or "
-                   "multiple of 4 for binary to wide string" );
+    // TO convert a binary to a system string or a binary to a wide string, the buffer size minus 
+    // 'extra' is ideally multiples of 2 or 4 (depending on Char), but calculating to_copy_hex below
+    // takes care of this.
 
-    // all fields will be treated as ODBC returns varchar(max) fields:
+    // All fields will be treated as ODBC returns varchar(max) fields:
     // the entire length of the string is returned the first
     // call in out_buffer_len.  Successive calls return how much is
     // left minus how much has already been read by previous reads
-    // *2 is for each byte to hex conversion and * extra is for either system or wide string allocation
+    // *2 is for each byte to hex conversion and * extra is for either system 
+    // or wide string allocation
     *out_buffer_length = (*reinterpret_cast<SQLLEN*>( field_data - sizeof( SQLULEN )) - read_so_far) * 2 * extra;
 
-    // copy as much as we can into the buffer
+    // Will copy as much as we can into the buffer
     SQLLEN to_copy;
     if( buffer_length < *out_buffer_length + extra ) {
         to_copy = (buffer_length - extra);
@@ -975,14 +917,14 @@ SQLRETURN binary_to_string( _Inout_ SQLCHAR* field_data, _Inout_ SQLLEN& read_so
         to_copy = *out_buffer_length;
     }
 
-    // if there are bytes to copy as hex
+    // If there are bytes to copy as hex
     if( to_copy > 0 ) {
         // quick hex conversion routine
-        Char* h = reinterpret_cast<Char*>( buffer );
-        BYTE* b = reinterpret_cast<BYTE*>( field_data );
+        Char* h = reinterpret_cast<Char*>(buffer);
+        BYTE* b = reinterpret_cast<BYTE*>(field_data + read_so_far);
         // to_copy contains the number of bytes to copy, so we divide the number in half (or quarter)
-        // to get the number of hex digits we can copy
-        SQLLEN to_copy_hex = to_copy / (2 * extra);
+        // to get the maximum number of hex digits to copy
+        SQLLEN to_copy_hex = static_cast<SQLLEN>(floor(to_copy / (2 * extra)));
         for( SQLLEN i = 0; i < to_copy_hex; ++i ) {
             *h = hex_chars[(*b & 0xf0) >> 4];
             h++;
@@ -990,7 +932,7 @@ SQLRETURN binary_to_string( _Inout_ SQLCHAR* field_data, _Inout_ SQLLEN& read_so
             h++;
         }
         read_so_far += to_copy_hex;
-        *h = static_cast<Char>( 0 );
+        *h = static_cast<Char>(0);
     }
     else {
         reinterpret_cast<char*>( buffer )[0] = '\0';
@@ -1082,23 +1024,6 @@ SQLRETURN sqlsrv_buffered_result_set::double_to_system_string( _In_ SQLSMALLINT
     return r;
 }
 
-SQLRETURN sqlsrv_buffered_result_set::double_to_wide_string( _In_ SQLSMALLINT field_index, _Out_writes_bytes_to_opt_(buffer_length, *out_buffer_length) void* buffer, _In_ SQLLEN buffer_length,
-                                                             _Inout_ SQLLEN* out_buffer_length )
-{
-    SQLSRV_ASSERT( meta[field_index].c_type == SQL_C_DOUBLE, "Invalid conversion to wide string" );
-    SQLSRV_ASSERT( buffer_length > 0, "Buffer length must be > 0 in sqlsrv_buffered_result_set::double_to_wide_string" );
-
-    unsigned char* row = get_row();
-    double* double_data = reinterpret_cast<double*>( &row[meta[field_index].offset] );
-    SQLRETURN r = SQL_SUCCESS;
-#ifdef _WIN32
-    r = number_to_string<WCHAR>( double_data, buffer, buffer_length, out_buffer_length, last_error );
-#else
-    r = number_to_string<char16_t, double>( double_data, buffer, buffer_length, out_buffer_length, last_error );
-#endif // _WIN32
-    return r;
-}
-
 SQLRETURN sqlsrv_buffered_result_set::long_to_double( _In_ SQLSMALLINT field_index, _Out_writes_bytes_(*out_buffer_length) void* buffer, _In_ SQLLEN buffer_length, 
                                                       _Out_ SQLLEN* out_buffer_length )
 {
@@ -1131,23 +1056,6 @@ SQLRETURN sqlsrv_buffered_result_set::long_to_system_string( _In_ SQLSMALLINT fi
     return r;
 }
 
-SQLRETURN sqlsrv_buffered_result_set::long_to_wide_string( _In_ SQLSMALLINT field_index, _Out_writes_bytes_to_opt_(buffer_length, *out_buffer_length) void* buffer, _In_ SQLLEN buffer_length,
-                                                           _Inout_ SQLLEN* out_buffer_length )
-{
-    SQLSRV_ASSERT( meta[field_index].c_type == SQL_C_LONG, "Invalid conversion to wide string" );
-    SQLSRV_ASSERT( buffer_length > 0, "Buffer length must be > 0 in sqlsrv_buffered_result_set::long_to_wide_string" );
-
-    unsigned char* row = get_row();
-    LONG* long_data = reinterpret_cast<LONG*>( &row[meta[field_index].offset] );
-    SQLRETURN r = SQL_SUCCESS;
-#ifdef _WIN32
-    r = number_to_string<WCHAR>( long_data, buffer, buffer_length, out_buffer_length, last_error );
-#else
-    r = number_to_string<char16_t, LONG>( long_data, buffer, buffer_length, out_buffer_length, last_error );
-#endif // _WIN32
-    return r;
-}
-
 SQLRETURN sqlsrv_buffered_result_set::string_to_double( _In_ SQLSMALLINT field_index, _Out_writes_bytes_(*out_buffer_length) void* buffer, _In_ SQLLEN buffer_length,
                                                         _Inout_ SQLLEN* out_buffer_length )
 {
@@ -1157,7 +1065,16 @@ SQLRETURN sqlsrv_buffered_result_set::string_to_double( _In_ SQLSMALLINT field_i
     unsigned char* row = get_row();
     char* string_data = reinterpret_cast<char*>( &row[meta[field_index].offset] ) + sizeof( SQLULEN );
 
-    return string_to_number<double>( string_data, meta[field_index].length, buffer, buffer_length, out_buffer_length, last_error );
+    double* number_data = reinterpret_cast<double*>(buffer);
+    try {
+        *number_data = std::stod(std::string(string_data));
+    } catch (const std::logic_error& ) {
+        last_error = new (sqlsrv_malloc(sizeof(sqlsrv_error))) sqlsrv_error((SQLCHAR*) "22003", (SQLCHAR*) "Numeric value out of range", 103);
+        return SQL_ERROR;
+    }
+
+    *out_buffer_length = sizeof(double);
+    return SQL_SUCCESS;
 }
 
 SQLRETURN sqlsrv_buffered_result_set::wstring_to_double( _In_ SQLSMALLINT field_index, _Out_writes_bytes_(*out_buffer_length) void* buffer, _In_ SQLLEN buffer_length,
@@ -1169,7 +1086,20 @@ SQLRETURN sqlsrv_buffered_result_set::wstring_to_double( _In_ SQLSMALLINT field_
     unsigned char* row = get_row();
     SQLWCHAR* string_data = reinterpret_cast<SQLWCHAR*>( &row[meta[field_index].offset] ) + sizeof( SQLULEN ) / sizeof( SQLWCHAR );
 
-    return string_to_number<double>( string_data, meta[field_index].length, buffer, buffer_length, out_buffer_length, last_error );
+    double* number_data = reinterpret_cast<double*>(buffer);
+    try {
+#ifdef _WIN32
+        *number_data = std::stod(std::wstring(string_data));
+#else
+        *number_data = std::stod(getUTF8StringFromString(string_data));
+#endif // _WIN32
+    } catch (const std::logic_error& ) {
+        last_error = new (sqlsrv_malloc(sizeof(sqlsrv_error))) sqlsrv_error((SQLCHAR*) "22003", (SQLCHAR*) "Numeric value out of range", 103);
+        return SQL_ERROR;
+    }
+
+    *out_buffer_length = sizeof(double);
+    return SQL_SUCCESS;
 }
 
 SQLRETURN sqlsrv_buffered_result_set::string_to_long( _In_ SQLSMALLINT field_index, _Out_writes_bytes_(*out_buffer_length) void* buffer, _In_ SQLLEN buffer_length,
@@ -1181,7 +1111,16 @@ SQLRETURN sqlsrv_buffered_result_set::string_to_long( _In_ SQLSMALLINT field_ind
     unsigned char* row = get_row();
     char* string_data = reinterpret_cast<char*>( &row[meta[field_index].offset] ) + sizeof( SQLULEN );
 
-    return string_to_number<LONG>( string_data, meta[field_index].length, buffer, buffer_length, out_buffer_length, last_error );
+    LONG* number_data = reinterpret_cast<LONG*>(buffer);
+    try {
+        *number_data = std::stol(std::string(string_data));
+    } catch (const std::logic_error& ) {
+        last_error = new (sqlsrv_malloc(sizeof(sqlsrv_error))) sqlsrv_error((SQLCHAR*) "22003", (SQLCHAR*) "Numeric value out of range", 103);
+        return SQL_ERROR;
+    }
+
+    *out_buffer_length = sizeof(LONG);
+    return SQL_SUCCESS;
 }
 
 SQLRETURN sqlsrv_buffered_result_set::wstring_to_long( _In_ SQLSMALLINT field_index, _Out_writes_bytes_(*out_buffer_length) void* buffer, _In_ SQLLEN buffer_length,
@@ -1193,7 +1132,20 @@ SQLRETURN sqlsrv_buffered_result_set::wstring_to_long( _In_ SQLSMALLINT field_in
     unsigned char* row = get_row();
     SQLWCHAR* string_data = reinterpret_cast<SQLWCHAR*>( &row[meta[field_index].offset] ) + sizeof( SQLULEN ) / sizeof( SQLWCHAR );
 
-    return string_to_number<LONG>( string_data, meta[field_index].length, buffer, buffer_length, out_buffer_length, last_error );
+    LONG* number_data = reinterpret_cast<LONG*>(buffer);
+    try {
+#ifdef _WIN32
+        *number_data = std::stol(std::wstring(string_data));
+#else
+        *number_data = std::stol(getUTF8StringFromString(string_data));
+#endif // _WIN32
+    } catch (const std::logic_error& ) {
+        last_error = new (sqlsrv_malloc(sizeof(sqlsrv_error))) sqlsrv_error((SQLCHAR*) "22003", (SQLCHAR*) "Numeric value out of range", 103);
+        return SQL_ERROR;
+    }
+
+    *out_buffer_length = sizeof(LONG);
+    return SQL_SUCCESS;
 }
 
 SQLRETURN sqlsrv_buffered_result_set::system_to_wide_string( _In_ SQLSMALLINT field_index, _Out_writes_z_(*out_buffer_length) void* buffer, _In_ SQLLEN buffer_length, 
@@ -1518,7 +1470,7 @@ void cache_row_dtor( _In_ zval* data )
 }
 
 SQLPOINTER read_lob_field( _Inout_ sqlsrv_stmt* stmt, _In_ SQLUSMALLINT field_index, _In_ sqlsrv_buffered_result_set::meta_data& meta, 
-                           _In_ zend_long mem_used TSRMLS_DC )
+                           _In_ zend_long mem_used )
 {
     SQLSMALLINT extra = 0;
     SQLULEN* output_buffer_len = NULL;
@@ -1553,7 +1505,7 @@ SQLPOINTER read_lob_field( _Inout_ sqlsrv_stmt* stmt, _In_ SQLUSMALLINT field_in
 
         output_buffer_len = reinterpret_cast<SQLULEN*>( buffer.get() );
         r = core::SQLGetData( stmt, field_index + 1, meta.c_type, buffer.get() + already_read + sizeof( SQLULEN ),
-                              to_read - already_read + extra, &last_field_len, false /*handle_warning*/ TSRMLS_CC );
+                              to_read - already_read + extra, &last_field_len, false /*handle_warning*/ );
 
         // if the field is NULL, then return a NULL pointer
         if( last_field_len == SQL_NULL_DATA ) {
@@ -1574,7 +1526,7 @@ SQLPOINTER read_lob_field( _Inout_ sqlsrv_stmt* stmt, _In_ SQLUSMALLINT field_in
         else if( r == SQL_SUCCESS_WITH_INFO ) {
             SQLSMALLINT len;
             core::SQLGetDiagField( stmt, 1, SQL_DIAG_SQLSTATE, state, SQL_SQLSTATE_BUFSIZE, &len 
-                                   TSRMLS_CC );
+                                   );
 
             if( !is_truncated_warning( state )) {
                 break;
